@@ -1,6 +1,6 @@
 #import "RCTGoogleAnalyticsBridge.h"
-#import "RCTLog.h"
-#import "RCTConvert.h"
+#import <React/RCTLog.h>
+#import <React/RCTConvert.h>
 #import "GAI.h"
 #import "GAIFields.h"
 #import "GAIDictionaryBuilder.h"
